/*
 * ZIP archive handling / unzip
 *
 * Copyright (c) 2002 Jan Wassenberg
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * Contact info:
 *   Jan.Wassenberg@stud.uni-karlsruhe.de
 *   http://www.stud.uni-karlsruhe.de/~urkt/
 */

#ifndef __UNZIP_H__
#define __UNZIP_H__


/*
 * opens the zip file fn and returns its 'zip descriptor'
 * (a small, non-negative integer for use in unzip(), close_zip(), zip_error_str())
 *
 * returns -1 on error.
 *
 * NOTES:
 *  - does not update the error string!
 *  - all open zip files will be closed at exit
 */
extern int open_zip(const char* fn);

extern void close_zip(const int zip);

/*
 * extracts fn from the zip file zd;
 * returns a pointer to the data and (if size != NULL) its length in size
 *
 * returns NULL on error.
 *
 * NOTES:
 *  - it is the application's responsibility to deallocate
 *    memory returned by this function via free()
 */
extern void* unzip(const int zip, const char* fn, int* size);

/*
 * returns a string explaining the last error.
 * valid only after unzip() returns NULL and before
 * the next unzip() call with the same zip descriptor
 */
extern const char* zip_error_str(const int zip);


#endif	/* #ifndef __UNZIP_H__ */