/*
 * emulation of several POSIX calls for Win32
 *
 * Copyright (c) 2002 Jan Wassenberg
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * Contact info:
 *   Jan.Wassenberg@stud.uni-karlsruhe.de
 *   http://www.stud.uni-karlsruhe.de/~urkt/
 */

#include "precompiled.h"

#include "wposix.h"


DIR* opendir(const char* name)
{
	DWORD fa = GetFileAttributes(name);
	return (DIR*)(fa != -1 && fa & FILE_ATTRIBUTE_DIRECTORY);
}




void* mmap(void* start, uint len, int prot, int flags, int fd, long offset)
{
	/* Win32 functions require read access */
	if(!(prot&PROT_READ))
		return MAP_FAILED;

	/* interpret protection/mapping flags. */
	DWORD flProtect = PAGE_READONLY;	/* mapping object permission */
	DWORD dwAccess = FILE_MAP_READ;		/* file map access permission */
	if(prot&PROT_WRITE)
	{
		flProtect = PAGE_READWRITE;

		int write_mode = flags&(MAP_SHARED|MAP_PRIVATE);
		/* changes are written to file */
		if(write_mode == MAP_SHARED)
			dwAccess = FILE_MAP_WRITE;
		/* private copy on write mapping */
		else if(write_mode == MAP_PRIVATE)
			dwAccess = FILE_MAP_COPY;
		else
			return MAP_FAILED;	/* flags must contain exactly one of: */
								/* (MAP_SHARED, MAP_PRIVATE) */
	}

	/*
	 * convert fd to a Win32 HANDLE for use with CreateFileMapping().
	 * NOTE: open() calls CreateFile() and saves its HANDLE via _set_osfhandle()
	 */
	HANDLE hFile = (HANDLE)_get_osfhandle(fd);

	/* create a file mapping object */
	HANDLE hMap = CreateFileMapping(hFile, NULL, flProtect, 0, len, NULL);

	/* map the file */
	void* ptr = MapViewOfFileEx(hMap, dwAccess, 0, offset, len, start);

	/* free the file mapping object when ptr is unmapped */
	CloseHandle(hMap);

	return (ptr)? ptr : MAP_FAILED;
}
